@@ -119,29 +119,6 @@ class UrlActionCommentAt(UrlActionBase):
         )
 
 
-class UrlActionOpenBitmap(UrlActionBase):
-    def __init__(self, bitmap_path, base=None, md5=None, sha256=None):
-        super().__init__(md5, sha256)
-        self.bitmap_path = bitmap_path
-        self.base = base
-        self.md5 = md5
-        self.sha256 = sha256
-
-    def act(self, daemon_conn=None):
-        daemon_conn.root.openbitmap(
-            self.bitmap_path, self.base, self.md5, self.sha256)
-
-    @classmethod
-    def _from_params(cls, params):
-        url = cls._one_param(params, 'path')
-        return cls(
-            url,
-            base=cls._one_param(params, 'base'),
-            md5=cls._one_param(params, 'md5'),
-            sha256=cls._one_param(params, 'sha256'),
-        )
-
-
 class UrlActionBinaryAware(UrlActionBase):
     """
     The base class of all binary-aware URl actions.
@@ -180,7 +157,6 @@ _ACT2CLS = {
     'open': UrlActionOpen,
     'jumpto': UrlActionJumpTo,
     'commentat': UrlActionCommentAt,
-    'openbitmap': UrlActionOpenBitmap,
 }
 
 
