@@ -81,5 +81,6 @@ class CFGGenerationJob(Job):
             gui_thread_schedule_async(self._refresh, args=(cfg, self._cfb, ))
 
     def _refresh(self, cfg, cfb):
-        GlobalInfo.main_window.workspace.instance.async_set_cfg(cfg)
-        GlobalInfo.main_window.workspace.instance.async_set_cfb(cfb)
+        # do not signal events. that will happen on a timer to not overwhelm the renderer
+        GlobalInfo.main_window.workspace.instance.cfg = cfg
+        GlobalInfo.main_window.workspace.instance.cfb = cfb
