@@ -1,5 +1,5 @@
 from angrmanagement.plugins import BasePlugin
-from typing import List
+from typing import List, Iterator, Union, Tuple, Callable
 
 class SamplePlugin(BasePlugin):
     def __init__(self, workspace):
@@ -7,4 +7,7 @@ class SamplePlugin(BasePlugin):
 
         workspace.instance.register_container('bookmarks', lambda: [], List[int], 'Bookmarked addresses')
 
-    MENU_BUTTONS = ('Add Bookmark',)
\ No newline at end of file
+    MENU_BUTTONS = ('Add Bookmark',)
+
+    def build_context_menu_function(self, func): # pylint: disable=unused-argument
+        yield ("owo", [("uwu", lambda: None), ("o_O", lambda: None)])
