@@ -1,10 +1,11 @@
 import os
 import logging
+import sys
 from typing import Optional
 
-from PySide2.QtWidgets import QMainWindow, QTabWidget, QFileDialog, QInputDialog, QProgressBar
-from PySide2.QtWidgets import QMessageBox, QSplitter, QShortcut, QLineEdit
-from PySide2.QtGui import QResizeEvent, QIcon, QDesktopServices, QKeySequence, QColor
+from PySide2.QtWidgets import QMainWindow, QTabWidget, QFileDialog, QProgressBar
+from PySide2.QtWidgets import QMessageBox, QSplitter, QShortcut
+from PySide2.QtGui import QResizeEvent, QIcon, QDesktopServices, QKeySequence
 from PySide2.QtCore import Qt, QSize, QEvent, QTimer, QUrl
 
 import angr
@@ -31,17 +32,14 @@ from .menus.analyze_menu import AnalyzeMenu
 from .menus.help_menu import HelpMenu
 from .menus.view_menu import ViewMenu
 from .menus.plugin_menu import PluginMenu
-from .menus.sync_menu import SyncMenu
 from ..config import IMG_LOCATION
 from .workspace import Workspace
 from .dialogs.load_plugins import LoadPlugins
 from .dialogs.load_docker_prompt import LoadDockerPrompt, LoadDockerPromptError
 from .dialogs.new_state import NewState
-from .dialogs.sync_config import SyncConfig
 from .dialogs.about import LoadAboutDialog
 from .dialogs.preferences import Preferences
 from .toolbars import StatesToolbar, AnalysisToolbar, FileToolbar
-from ..utils import has_binsync
 from ..utils.io import isurl, download_url
 from ..errors import InvalidURLError, UnexpectedStatusCodeError
 from ..config import Conf
@@ -54,7 +52,7 @@ class MainWindow(QMainWindow):
     """
     The main window of angr management.
     """
-    def __init__(self, parent=None):
+    def __init__(self, parent=None, show=True):
         super(MainWindow, self).__init__(parent)
 
         icon_location = os.path.join(IMG_LOCATION, 'angr.png')
@@ -87,7 +85,6 @@ class MainWindow(QMainWindow):
         self._view_menu = None
         self._help_menu = None
         self._plugin_menu = None
-        self._sync_menu = None
 
         self._init_toolbars()
         self._init_statusbar()
@@ -96,13 +93,11 @@ class MainWindow(QMainWindow):
         self._init_menus()
         self._init_plugins()
 
-        self.showMaximized()
-
-        # event handlers
-        self.windowHandle().screenChanged.connect(self.on_screen_changed)
-
         # I'm ready to show off!
-        self.show()
+        if show:
+            self.showMaximized()
+            self.windowHandle().screenChanged.connect(self.on_screen_changed)
+            self.show()
 
         self.status = "Ready."
 
@@ -166,7 +161,7 @@ class MainWindow(QMainWindow):
         dlg.exec_()
 
     def open_newstate_dialog(self):
-        if self.workspace.instance.project is None:
+        if self.workspace.instance.project.am_none:
             QMessageBox.critical(self,
                                  "Cannot create new states",
                                  "Please open a binary to analyze first.")
@@ -177,14 +172,6 @@ class MainWindow(QMainWindow):
     def open_doc_link(self):
         QDesktopServices.openUrl(QUrl("https://docs.angr.io/", QUrl.TolerantMode))
 
-    def open_sync_config_dialog(self):
-        if self.workspace.instance.project is None:
-            # project does not exist yet
-            return
-
-        sync_config = SyncConfig(self.workspace.instance, parent=self)
-        sync_config.exec_()
-
     def open_about_dialog(self):
         dlg = LoadAboutDialog()
         dlg.exec_()
@@ -224,15 +211,14 @@ class MainWindow(QMainWindow):
         self._help_menu = HelpMenu(self)
         self._plugin_menu = PluginMenu(self)
 
+        # TODO: Eventually fix menu bars to have native support on MacOS
+        # if on a Mac, don't use the native menu bar (bug mitigation from QT)
+        if sys.platform == 'darwin':
+            self.menuBar().setNativeMenuBar(False)
+
         self.menuBar().addMenu(self._file_menu.qmenu())
         self.menuBar().addMenu(self._view_menu.qmenu())
         self.menuBar().addMenu(self._analyze_menu.qmenu())
-        if has_binsync():
-            self._sync_menu = SyncMenu(self)
-            self.menuBar().addMenu(self._sync_menu.qmenu())
-            def on_load(**kwargs):
-                self._sync_menu.action_by_key("config").enable()
-            self.workspace.instance._project_container.am_subscribe(on_load)
         self.menuBar().addMenu(self._plugin_menu.qmenu())
         self.menuBar().addMenu(self._help_menu.qmenu())
 
@@ -260,11 +246,13 @@ class MainWindow(QMainWindow):
         self.central_widget2.setTabPosition(Qt.LeftDockWidgetArea, QTabWidget.North)
 
         def set_caption(**kwargs):
-            if self.workspace.instance.project == None:
+            if self.workspace.instance.project.am_none:
                 self.caption = ''
+            elif self.workspace.instance.project.filename is None:
+                self.caption = "Loaded from stream"
             else:
                 self.caption = os.path.basename(self.workspace.instance.project.filename)
-        self.workspace.instance.project_container.am_subscribe(set_caption)
+        self.workspace.instance.project.am_subscribe(set_caption)
 
     #
     # Shortcuts
@@ -307,7 +295,7 @@ class MainWindow(QMainWindow):
     def closeEvent(self, event):
 
         # Ask if the user wants to save things
-        if self.workspace.instance is not None and self.workspace.instance.project is not None:
+        if self.workspace.instance is not None and not self.workspace.instance.project.am_none:
             msgbox = QMessageBox()
             msgbox.setWindowTitle("Save database")
             msgbox.setText("angr management is about to exit. Do you want to save the database?")
@@ -384,7 +372,7 @@ class MainWindow(QMainWindow):
             return
         target = archr.targets.DockerImageTarget(img_name, target_path=None)
         self.workspace.instance.add_job(LoadTargetJob(target))
-        self.workspace.instance.set_image(img_name)
+        self.workspace.instance.img_name = img_name
 
     def load_file(self, file_path):
 
@@ -439,7 +427,7 @@ class MainWindow(QMainWindow):
         self._load_database(file_path)
 
     def save_database(self):
-        if self.workspace.instance is None or self.workspace.instance.project is None:
+        if self.workspace.instance is None or self.workspace.instance.project.am_none:
             return True
 
         if self.workspace.instance.database_path is None:
@@ -449,7 +437,7 @@ class MainWindow(QMainWindow):
 
     def save_database_as(self):
 
-        if self.workspace.instance is None or self.workspace.instance.project is None:
+        if self.workspace.instance is None or self.workspace.instance.project.am_none:
             return False
 
         default_database_path = self.workspace.instance.database_path
@@ -495,12 +483,13 @@ class MainWindow(QMainWindow):
         if self.workspace is not None:
             self.workspace.decompile_current_function()
 
+    def view_proximity_for_current_function(self):
+        if self.workspace is not None:
+            self.workspace.view_proximity_for_current_function()
+
     def interact(self):
         self.workspace.interact_program(self.workspace.instance.img_name)
 
-    def setup_sync(self):
-        self.open_sync_config_dialog()
-
     #
     # Other public methods
     #
@@ -545,17 +534,18 @@ class MainWindow(QMainWindow):
 
         self.workspace.instance.database_path = file_path
 
-        self.workspace.instance.initialized = True  # skip automated CFG recovery
+        self.workspace.instance._reset_containers()
         self.workspace.instance.project = proj
         self.workspace.instance.cfg = cfg
         self.workspace.instance.cfb = cfb
+        self.workspace.instance.project.am_event(initialized=True)
 
         # trigger callbacks
         self.workspace.reload()
         self.workspace.on_cfg_generated()
 
     def _save_database(self, file_path):
-        if self.workspace.instance is None or self.workspace.instance.project is None:
+        if self.workspace.instance is None or self.workspace.instance.project.am_none:
             return False
 
         if AngrDB is None:
