@@ -13,6 +13,9 @@ class AnalyzeMenu(Menu):
             MenuEntry('&Decompile',
                 main_window.decompile_current_function,
                 shortcut=QKeySequence(Qt.Key_F5)),
+            MenuEntry('View in Proximity &Browser',
+                      main_window.view_proximity_for_current_function,
+                      shortcut=QKeySequence(Qt.CTRL + Qt.Key_B)),
             MenuEntry('&Interact',
                 main_window.interact,
                 shortcut=QKeySequence(Qt.Key_F6)),])
