@@ -11,29 +11,21 @@ class MenuEntry:
         self.default_enabled = enabled
         self.key = key
 
-        self._qaction = None
+        self.qaction = None
 
     def enable(self):
-        if self._qaction is not None:
-            self._qaction.setDisabled(False)
+        if self.qaction is not None:
+            self.qaction.setDisabled(False)
 
     def disable(self):
-        if self._qaction is not None:
-            self._qaction.setDisabled(True)
-
-    @property
-    def qaction(self):
-        return self._qaction
-
-    @qaction.setter
-    def qaction(self, v):
-        self._qaction = v
+        if self.qaction is not None:
+            self.qaction.setDisabled(True)
 
     @property
     def checked(self):
-        if self._qaction is None or not self.checkable:
+        if self.qaction is None or not self.checkable:
             return False
-        return self._qaction.isChecked()
+        return self.qaction.isChecked()
 
 
 class MenuSeparator:
@@ -42,7 +34,7 @@ class MenuSeparator:
 
 
 class Menu:
-    def __init__(self, caption, parent=None):
+    def __init__(self, caption, children=(), parent=None):
 
         self.parent = parent
         self.caption = caption
@@ -52,6 +44,9 @@ class Menu:
 
         self._qmenu = None  # type: QMenu
 
+        for child in children:
+            self.add(child)
+
     def action_by_key(self, key):
         if not self._keyed_entries:
             self._keyed_entries = dict((ent.key, ent) for ent in
@@ -61,8 +56,6 @@ class Menu:
     def qmenu(self, extra_entries=None):
         if extra_entries is None:
             extra_entries = []
-        else:
-            extra_entries = [MenuSeparator() if entry is None else MenuEntry(*entry) for entry in extra_entries]
 
         if not extra_entries and self._qmenu is not None:
             # in order to use the cached result, must not have extra entries
@@ -74,7 +67,7 @@ class Menu:
             menu = QMenu(self.caption)
 
         for entry in self.entries + extra_entries:
-            self._translate_element(menu, entry)
+            self.translate_element(menu, entry)
 
         # in order to cache the result, must not have extra entries
         if not extra_entries:
@@ -82,9 +75,17 @@ class Menu:
 
         return menu
 
-    def _translate_element(self, menu, entry):
+    @staticmethod
+    def translate_element(menu, entry):
+        if entry is None:
+            entry = MenuSeparator()
+        elif type(entry) is tuple and len(entry) == 2 and callable(entry[1]):
+            entry = MenuEntry(*entry)
+        elif type(entry) is tuple and len(entry) == 2 and hasattr(entry[1], '__iter__'):
+            entry = Menu(*entry)
+
         if isinstance(entry, MenuEntry):
-            action = menu.addAction(entry.caption, entry.action)  # type: QAction
+            action: QAction = menu.addAction(entry.caption, entry.action)
             if entry.shortcut is not None:
                 action.setShortcut(entry.shortcut)
             if entry.checkable:
@@ -95,15 +96,21 @@ class Menu:
             entry.qaction = action
         elif isinstance(entry, MenuSeparator):
             menu.addSeparator()
+        elif isinstance(entry, Menu):
+            menu.addMenu(entry.qmenu())
+        elif isinstance(entry, QMenu):
+            menu.addMenu(entry)
+        elif isinstance(entry, QAction):
+            menu.addAction(entry)
         else:
             raise TypeError('Unsupported type', type(entry))
 
     def add(self, action):
         self.entries.append(action)
         if self._qmenu is not None:
-            self._translate_element(self._qmenu, action)
+            self.translate_element(self._qmenu, action)
 
     def remove(self, action):
         self.entries.remove(action)
         if self._qmenu is not None and type(action) is MenuEntry:
-            self._qmenu.removeAction(action._qaction)
+            self._qmenu.removeAction(action.qaction)
