@@ -1,5 +1,5 @@
 import logging
-from typing import Optional, TYPE_CHECKING
+from typing import Union, Optional, TYPE_CHECKING
 
 from PySide2.QtWidgets import QHBoxLayout, QVBoxLayout, QMenu, QApplication, QMessageBox
 from PySide2.QtCore import Qt, QSize
@@ -59,12 +59,13 @@ class DisassemblyView(BaseView):
 
     def reload(self):
 
+        old_infodock = self.infodock.copy()
+
         self.infodock.initialize()
         self._feature_map.refresh()
 
-        # Initialize the linear viewer
-        # TODO: Relocate the logic to a better place
-        self._linear_viewer.initialize()
+        # Reload the current graph to make sure it gets the latest information, such as variables.
+        self.current_graph.reload(old_infodock=old_infodock)
 
     def refresh(self):
         self.current_graph.refresh()
@@ -121,18 +122,21 @@ class DisassemblyView(BaseView):
                 # TODO: Rerun the variable recovery analysis and update the current view
 
     @property
-    def current_graph(self):
+    def current_graph(self) -> Union[QLinearDisassemblyView,QDisassemblyGraph]:
         """
         Return the current disassembly control, either linear viewer or flow graph.
 
         :return:    Linear viewer or flow graph.
-        :rtype:     QLinearDisassembly or QDisassemblyGraph
         """
         if self._linear_viewer.isVisible():
             return self._linear_viewer
         else:
             return self._flow_graph
 
+    @property
+    def current_function(self) -> ObjectContainer:
+        return self._current_function
+
     #
     # Callbacks
     #
@@ -168,12 +172,24 @@ class DisassemblyView(BaseView):
     #
 
     def keyPressEvent(self, event):
+        key = event.key()
+        if key == Qt.Key_Escape:
+            # jump back
+            # we put it here because the escape key is used to close other dialogs, and we do not want to catch the
+            # key-release event of the escape key in such cases.
+            self.jump_back()
+            return
+
+        super().keyPressEvent(event)
+
+
+    def keyReleaseEvent(self, event):
         key = event.key()
         if key == Qt.Key_G:
             # jump to window
             self.popup_jumpto_dialog()
             return
-        elif key == Qt.Key_Escape or (key == Qt.Key_Left and QApplication.keyboardModifiers() & Qt.ALT != 0):
+        elif key == Qt.Key_Left and QApplication.keyboardModifiers() & Qt.ALT != 0:
             # jump back
             self.jump_back()
             return
@@ -193,12 +209,7 @@ class DisassemblyView(BaseView):
             # add comment
             self.popup_comment_dialog()
             return
-        super().keyPressEvent(event)
-
-    def keyReleaseEvent(self, event):
-        key = event.key()
-
-        if key == Qt.Key_Space:
+        elif key == Qt.Key_Space:
             # switch to linear view
             self.toggle_disasm_view()
             event.accept()
@@ -277,18 +288,23 @@ class DisassemblyView(BaseView):
             if r is not None:
                 _, addr, operand = r
             else:
-                QMessageBox(self,
-                            "No operand"
-                            "Please select an operand first.",
-                            buttons=QMessageBox.Ok,
-                            icon=QMessageBox.Critical
-                            )
+                QMessageBox.critical(self,
+                                     "No operand",
+                                     "Please select an operand first.",
+                                     buttons=QMessageBox.Ok,
+                                     )
                 return
         else:
             if addr is None:
                 raise ValueError("No address is provided.")  # this is a programming error
             operand = None
 
+        # if a function target is selected, switch to function mode
+        if operand is not None and not func:
+            if operand._branch_target is not None and operand._is_target_func:
+                func = True
+                addr = operand._branch_target
+
         if func:
             # attempt to pass in a function
             try:
@@ -380,7 +396,12 @@ class DisassemblyView(BaseView):
     def decompile_current_function(self):
 
         if self._current_function.am_obj is not None:
-            self.workspace.decompile_function(self._current_function.am_obj)
+            try:
+                curr_ins = next(iter(self.infodock.selected_insns))
+            except StopIteration:
+                curr_ins = None
+
+            self.workspace.decompile_function(self._current_function.am_obj, curr_ins=curr_ins)
 
     def toggle_smart_highlighting(self, enabled):
         """
