@@ -1,4 +1,4 @@
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Optional
 import logging
 import traceback
 
@@ -11,11 +11,10 @@ from ..config import Conf
 from ..data.instance import ObjectContainer
 from ..data.jobs import CodeTaggingJob, PrototypeFindingJob, VariableRecoveryJob
 from .views import (FunctionsView, DisassemblyView, SymexecView, StatesView, StringsView, ConsoleView, CodeView,
-                    InteractionView, SyncView, PatchesView, DependencyView, )
+                    InteractionView, PatchesView, DependencyView, ProximityView)
 from .widgets.qsmart_dockwidget import QSmartDockWidget
 from .view_manager import ViewManager
 
-from ..utils import has_binsync
 from ..plugins import PluginManager
 
 if TYPE_CHECKING:
@@ -46,6 +45,7 @@ class Workspace:
         self.default_tabs = [
             FunctionsView(self, 'left'),
             DisassemblyView(self, 'center'),
+            ProximityView(self, 'center'),
             CodeView(self, 'center'),
         ]
         if Conf.has_operation_mango:
@@ -61,9 +61,6 @@ class Workspace:
             ConsoleView(self, 'bottom'),
         ]
 
-        if has_binsync():
-            self.default_tabs.append(SyncView(self, 'right'))
-
         #
         # Save initial splitter state
         #
@@ -91,7 +88,7 @@ class Workspace:
         self._get_or_create_disassembly_view().display_function(func)
         codeview = self.view_manager.first_view_in_category('pseudocode')
         if codeview is not None and codeview.is_shown():
-            self.decompile_function(func, codeview)
+            self.decompile_function(func, view=codeview)
 
     def on_cfg_generated(self):
 
@@ -110,6 +107,9 @@ class Workspace:
             if the_func is not None:
                 self.on_function_selected(the_func)
 
+            # Initialize the linear viewer
+            self.view_manager.first_view_in_category('disassembly')._linear_viewer.initialize()
+
     def _on_prototype_found(self):
         self.instance.add_job(
             VariableRecoveryJob(
@@ -125,7 +125,11 @@ class Workspace:
         )
 
     def on_function_tagged(self):
-        pass
+        view = self.view_manager.first_view_in_category('disassembly')
+        if view is not None:
+            view: DisassemblyView
+            if view.current_function.am_obj is not None:
+                view.reload()
 
     #
     # Public methods
@@ -156,6 +160,9 @@ class Workspace:
     def add_view(self, view, caption, category):
         self.view_manager.add_view(view, caption, category)
 
+    def remove_view(self, view):
+        self.view_manager.remove_view(view)
+
     def unsplit_view(self):
         """
         Unsplit view if it is already split
@@ -181,7 +188,6 @@ class Workspace:
     def toggle_split(self):
         """
         Toggles the split state
-        
         :return:    None
         """
 
@@ -264,13 +270,42 @@ class Workspace:
 
         view.decompile_current_function()
 
-    def decompile_function(self, func, view=None):
-        """
-        Decompile a function and switch to the pseudocode view.
+    def view_proximity_for_current_function(self, view=None):
+        if view is None or view.category != "proximity":
+            view = self._get_or_create_proximity_view()
 
-        :param Function func:   The function to decompile.
-        :param view:    The pseudocode view to raise.
-        :return:        None
+        disasm_view = self._get_or_create_disassembly_view()
+        if disasm_view.current_function is not None:
+            view.function = disasm_view.current_function.am_obj
+
+        self.raise_view(view)
+
+    def position_cursor_on_decomp(self, view, curr_ins):
+        if view is not None and curr_ins is not None:
+            # get the Qt document
+            doc = view.document
+
+            # get closest node for ins
+            new_text_pos = doc.find_closest_node_pos(curr_ins)
+
+            if new_text_pos is not None:
+                # set the new cursor position
+                textedit = view.textedit
+                cursor = textedit.textCursor()
+                cursor.setPosition(new_text_pos)
+                textedit.setTextCursor(cursor)
+                textedit.setFocus()
+
+    def decompile_function(self, func: Function, curr_ins=None, view=None):
+        """
+        Decompile a function a switch to decompiled view. If curr_ins is
+        defined, then also switch cursor focus to the position associated
+        with the asm instruction addr
+
+        :param func: The function to decompile
+        :param curr_ins: The instruction the cursor was at before switching to decompiled view
+        :param view: The decompiled qt text view
+        :return:
         """
 
         if view is None or view.category != "pseudocode":
@@ -280,6 +315,9 @@ class Workspace:
         self.raise_view(view)
         view.setFocus()
 
+        # correspond disass location to new decomp position
+        self.position_cursor_on_decomp(view, curr_ins)
+
     def create_simulation_manager(self, state, state_name, view=None):
 
         inst = self.instance
@@ -318,7 +356,7 @@ class Workspace:
     # Private methods
     #
 
-    def _get_or_create_disassembly_view(self):
+    def _get_or_create_disassembly_view(self) -> DisassemblyView:
         # Take the first disassembly view
         view = self.view_manager.first_view_in_category("disassembly")
 
@@ -359,10 +397,23 @@ class Workspace:
             self.add_view(view, view.caption, view.category)
         return view
 
+    def _get_or_create_proximity_view(self) -> ProximityView:
+        # Take the first proximity view
+        view = self.view_manager.first_view_in_category("proximity")
+
+        if view is None:
+            # Create a new proximity view
+            view = ProximityView(self, 'center')
+            self.add_view(view, view.caption, view.category)
+
+        return view
+
     #
     # UI-related Callback Setters & Manipulation
     #
 
+    # TODO: should these be removed? Nobody is using them and there is equivalent functionality elsewhere.
+
     from typing import Callable
     from angr.knowledge_plugins.functions.function import Function as angrFunc
     from .menus.disasm_insn_context_menu import DisasmInsnContextMenu
